@@ -104,8 +104,8 @@ class GatewayServer(threading.Thread):
     config = Config()
     config.bind = [f'0.0.0.0:{self.port}']
     config.loglevel = 'INFO'
-    config.accesslog = '.'
-    config.errorlog = '.'
+    config.accesslog = '-'
+    config.errorlog = '-'
     logging.getLogger('hypercorn.access').setLevel(logging.INFO)
     asyncio.run(serve(app, config))
 
